
#Root survivorship curve data and cox regression model details corresponding to the Fig. 10
##Title of Paper:  Linking above- and belowground phenology of hybrid walnut growing along a climatic gradient in temperate agroforestry systems
#Authors: Awaz Mohamed, Alexia Stokes, Zhun Mao, Christophe Jourdan, Sylvie Sabatier, Franois Pailler, Stephane Fourtier, Lydie Dufour, Yogan Monnier
#---------------------------------------------------------------------------

library (doBy) # to use the function "summaryBy()"
library (survival)

addr_input = ""
addr_output = addr_input


##############
brutV = c ("Mediterranean.csv", 
           "continental.csv", 
           "oceanic.csv")
brutDF = data.frame ()
for (file in brutV) {
  print (file)
  db=read.csv (file = paste (addr_input, file, sep =""), header = T, sep = ";" )
  brutDF = rbind (brutDF, db)
}

columnsToDeleteV = c ("row.names","Diameter_cm", "Length_cm","root_name","root", " Type", "Period", "Date_period", "DiameterClasses")
brutDF = brutDF[, ! (names (brutDF) %in% columnsToDeleteV )]

names (brutDF) = gsub (".","_", names (brutDF), fixed = T)
brutDF$RER_mm_day = round (brutDF$RER_mm_day, digits = 2)
# 20160921: Mao: I created a new column called "RER_mm_day2", in which I make root growth = -1, if the root is dead.
brutDF$RER_mm_day2 = with (brutDF, ifelse (Mortality == "D", -1, RER_mm_day) )

#summary (brutDF)
brutDF = brutDF [brutDF$DepthLevel == "D1",]
brutDF$Date2 =  as.POSIXlt(brutDF$Date, format="%d/%m/%Y")
brutDF$DateSeq = round(as.numeric (difftime(brutDF$Date2 ,min (brutDF$Date2) , units = c("days"))),0) +1 
#
# creat an root ID unique for each root
brutDF$RootID = factor(with (brutDF, 
                             ifelse (RootName<10, paste (substr(Site, 1, 1), Rhizotron, paste ("00",RootName,sep=""), sep = "_"),
                                     ifelse (RootName<100, paste (substr(Site, 1, 1), Rhizotron, paste ("0",RootName,sep=""), sep = "_"),
                                             paste (substr(Site, 1, 1), Rhizotron, paste ("",RootName,sep=""), sep = "_") )  )))
# different from Mortality, "Die" will indicate the date when the root died.
brutDF$Die = NA
for (r in 2: nrow (brutDF)) {
  info_1 = paste(brutDF$Mortality[r-1])
  rootID_1 = paste(brutDF$RootID[r-1])
  info = paste(brutDF$Mortality[r])
  rootID = paste(brutDF$RootID[r])
  if ((info == "D" & info != info_1) & rootID == rootID_1 ) {
    brutDF$Die[r] = 1
  }
}




# This is the main diameter classification
brutDF$DiamClass3 = with (brutDF, ifelse (Diameter_mm<=1.0, "0-1",
                                          ifelse (Diameter_mm<=2.0, "1-2", "2-5")))
# This is the minor diameter classification (just for RIQ and RMQ)
brutDF$DiamClass4 = with (brutDF, ifelse (Diameter_mm<=0.5, "0-0.5",
                                          ifelse (Diameter_mm<=1, "0.5-1",
                                                  ifelse (Diameter_mm<=2, "1-2", "2-5"))))
table (brutDF$Topology, brutDF$DiamClass3, brutDF$Site)
#table (brutDF$Topology, brutDF$DiamClass4, brutDF$Site )

fractionL = strsplit (x = paste(brutDF$Date), split = "/")
brutDF$Year  = sapply (fractionL, FUN = function (x) {as.numeric(x[3])} )
brutDF$Month = sapply (fractionL, FUN = function (x) {as.numeric(x[2])} )
brutDF$Day   = sapply (fractionL, FUN = function (x) {as.numeric(x[1])} )
brutDF =  brutDF[with (brutDF, order(Site, Rhizotron,RootID, Year, Month, Day, DateSeq, Topology, seq_period1)) , ]


write.csv (brutDF, file =paste (addr_output, gsub("-", "", Sys.Date()), "_brutDF_3sites_withTopo.csv", sep = ""),
           row.names =F)


########
# Calculate the metrics

file = "20170810_brutDF_3sites_withTopo.csv"
brutDF = read.csv (file = paste (addr_input, file, sep =""), header = T, sep = "," )



NRootG = function (x) {
  y= length(x[x> 0 & is.na (x) ])  # Note: if RER_mm_day is NA, it means this is a new root.
  return (y)
}

NRootA = function (x) { # A means Alive (including growing roots and non-growing roots)
  y= length(x[x> -1 | is.na (x) ]) # Note: if RER_mm_day is NA, it means this is a new root.
  return (y)
}

mean2 = function (x) {
  y = x[x>0 & (!is.na (x))]
  if (length (y) == 0) {y2 = NA}
  else
  {y2 = round (mean (y), 2)}
  return (y2)
}

riq = function (x) {
  y = length(x[(is.na (x))])
  return (y)
}




brut3DF = summaryBy (formula = RER_mm_day2 ~ Site + Rhizotron + DiamClass3 + Topology + Date2 + seq_period1 + Seq,
                     data = brutDF,
                     FUN = c (length, NRootG, NRootA, mean2, riq))

#
rmqDF= summaryBy (formula = Die ~ Site + Rhizotron + DiamClass3 + Topology  + Date2 +  seq_period1 + Seq,
                  data = brutDF,
                  FUN = c (sum), na.rm = T)


names (brut3DF)[names (brut3DF) %in% "RER_mm_day2.length" ] = "Nroot_notused" # unit: # of roots
names (brut3DF)[ names (brut3DF) %in% "RER_mm_day2.NRootG" ] = "NRootG_notused" # unit: # of roots
names (brut3DF)[ names (brut3DF) %in% "RER_mm_day2.NRootA" ] = "NRootA_notused" # unit: # of roots
brut3DF[["Pnon0"]] = with (brut3DF,ifelse (NRootA_notused == 0, 0, round (NRootG_notused/NRootA_notused *100, 1) )) # unit: %

names (brut3DF)[ names (brut3DF) %in% "RER_mm_day2.riq" ] = "RIQ_notused" # unit: mm/day
brut3DF$RMQ_notused = rmqDF$Die.sum
brut3DF$Topology = gsub (" ", "", brut3DF$Topology)
brut3DF$Topology = gsub (" ", "", brut3DF$Topology)

brut3DF$Nroot = round (with (brut3DF, ifelse (Site == "Mediterranean" & Rhizotron == "A1", Nroot_notused / (80*35) * (50*50), 
                                              ifelse (Site == "Mediterranean", Nroot_notused / (30*65) * (50*50), Nroot_notused))) ,0)
brut3DF$NrootG = round (with (brut3DF, ifelse (Site == "Mediterranean" & Rhizotron == "A1", NRootG_notused / (80*35) * (50*50), 
                                               ifelse (Site == "Mediterranean", NRootG_notused / (30*65) * (50*50), NRootG_notused))) ,0)
brut3DF$NrootA = round (with (brut3DF, ifelse (Site == "Mediterranean" & Rhizotron == "A1", NRootA_notused / (80*35) * (50*50), 
                                               ifelse (Site == "Mediterranean", NRootA_notused / (30*65) * (50*50), NRootA_notused))) ,0)

brut3DF$RIQ = round (with (brut3DF, ifelse (Site == "Mediterranean" & Rhizotron == "A1", RIQ_notused / (80*35) * (50*50), 
                                            ifelse (Site == "Mediterranean", RIQ_notused / (30*65) * (50*50), RIQ_notused))) ,0)
brut3DF$RMQ = round (with (brut3DF, ifelse (Site == "Mediterranean" & Rhizotron == "A1", RMQ_notused / (80*35) * (50*50), 
                                            ifelse (Site == "Mediterranean", RMQ_notused / (30*65) * (50*50), RMQ_notused))) ,0)
#
write.csv (brut3DF, file =paste (addr_output, gsub("-", "", Sys.Date()), "_brut3DF_3sites_withTopo.csv", sep = ""),
           row.names =F)




st = function (x) {x[1]}
np = function (x) {length (unique (x))} # num of period the root occupes
#
survivDF = summaryBy (formula = seq_period1 + Year + Month + Day+  DateSeq ~ Site + Rhizotron  + RootID ,
                      data = brutDF,
                      FUN = c (st))


survivDF$Topology.st = NA
survivDF$DiamClass3.st = NA
survivDF$DateEnd = NA
allRootsV = levels(survivDF$RootID)

for (root in allRootsV) {
  db = brutDF[brutDF$RootID == root,]
  survivDF$Topology.st[survivDF$RootID == root]  = paste(db$Topology[1])
  survivDF$DiamClass3.st[survivDF$RootID == root] = paste(db$DiamClass3[1])
  if (1 %in% db$Die ) {
    end = db[grep(1, db$Die), "DateSeq"]
    if (length (end) == 1) {
      survivDF$DateEnd[survivDF$RootID == root] = end
    }
    else {
      print (paste ("RootID: ",root, "#end: ",end ))
    }
  }
}




#
survivDF$Age = survivDF$DateEnd - survivDF$DateSeq.st

# Now, I want to calculate the censored (0) and non-senored (dead) roots to have more roots participating in the calculation
#test = survivDF[is.na (survivDF$Age),]
lastObsDateDF = data.frame (Site = c ("continental", "Mediterranean", "oceanic"),
                            Date = c ("09/06/2016", "12/05/2016","06/06/2016"))
lastObsDateDF$Date2 =  as.POSIXlt(lastObsDateDF$Date, format="%d/%m/%Y")
brutDF$Date2 =  as.POSIXlt(brutDF$Date, format="%d/%m/%Y")
lastObsDateDF$DateSeq = round(as.numeric (difftime(lastObsDateDF$Date2 , min (brutDF$Date2) , units = c("days"))),0) +1 


survivDF$Status = ifelse (is.na(survivDF$Age), 0, 1) # 0 : alive; 1: dead (occurence of the event)
survivDF$ALiveDays = with (survivDF,ifelse (Status == 1, survivDF$Age,
                                            ifelse (Site == "continental", lastObsDateDF[lastObsDateDF$Site == "continental", "DateSeq"] - DateSeq.st,
                                                    ifelse (Site == "Mediterranean", lastObsDateDF[lastObsDateDF$Site == "Mediterranean", "DateSeq"] - DateSeq.st,
                                                            ifelse (Site == "oceanic", lastObsDateDF[lastObsDateDF$Site == "oceanic", "DateSeq"] - DateSeq.st, NA)))))

#############  Now we have our "ALiveDays" wich which we plot survivorship curves ############
#
surviv2DF = survivDF[ !is.na(survivDF$ALiveDays), ]
# Effect of period
surviv2DF$Period = factor(paste ("P",surviv2DF$seq_period1.st, sep = "") , 
                          levels = c ("P3", "P1", "P2"))
surviv2DF$Topology.st = factor (gsub (" ","", surviv2DF$Topology.st))
surviv2DF$TopoDiam = factor(with (surviv2DF, paste (Topology.st, DiamClass3.st, sep = "_" )))
write.csv (surviv2DF, file =paste (addr_output, gsub("-", "", Sys.Date()), "_surviv2DF_3sites_withTopo.csv", sep = ""),
           row.names =F)
file = "20170810_surviv2DF_3sites_withTopo.csv"
surviv2DF = read.csv (file = paste (addr_input, file, sep =""), header = T, sep = "," )
surviv2DF$Period = factor(paste ("P",surviv2DF$seq_period1.st, sep = "") , 
                          levels = c ("P3", "P1", "P2"))



kmfit1 = survfit (Surv (ALiveDays, Status) ~ Site, data = surviv2DF)

table (surviv2DF$Site, surviv2DF$Period)
kmfit2 = survfit (Surv (ALiveDays, Status) ~ Site + Period, data = surviv2DF)
kmfit3 = survfit (Surv (ALiveDays, Status) ~ Site + DiamClass3.st , data = surviv2DF )
kmfit3r = survfit (Surv (ALiveDays, Status) ~ Site + DiamClass3.st , 
                   data = surviv2DF[surviv2DF$Topology.st == "root",] )
surviv3DF = surviv2DF[surviv2DF$DiamClass3.st != "2-5" & surviv2DF$Site != "oceanic",]
surviv3DF$TopoDiam = factor (surviv3DF$TopoDiam, 
                             levels =c ("lat_0-1", "root_0-1", "lat_1-2","root_1-2") )
kmfit4_noOnoCR = survfit (Surv (ALiveDays, Status) ~ Site + TopoDiam , 
                          data = surviv3DF )


getDF = function (x) {
  y = vector ()
  namesV = names(x) [ ! (names(x) %in% c ("n", "strata", "call", "type" ,"na.action","conf.type"))]
  for (name in namesV) {
    v = x[[name]]
    y = cbind (y,v)
  }
  y = as.data.frame(y)
  names (y) = namesV
  return (y)
}

#######
# for fig (a)
# Prepare the DF for kmfit1DF
kmfit1DF = getDF(kmfit1)
kmfit1DF = as.data.frame (apply(kmfit1DF, 2, as.numeric) )
myseq = rep(1, nrow (kmfit1DF))
for (row in 2:nrow (kmfit1DF)) {
  if (kmfit1DF$time[row] > kmfit1DF$time[row-1]) {
    myseq[row] = myseq[row-1]
  }
  else myseq[row] = myseq[row-1] + 1
}

kmfit1DF$Site = factor (ifelse (myseq == 1, "continental", 
                                ifelse (myseq == 2, "Mediterranean", 
                                        ifelse (myseq == 3, "oceanic",NA))))

# for fig (b)
kmfit2DF = getDF(kmfit2)
kmfit2DF = as.data.frame (apply(kmfit2DF, 2, as.numeric) )
myseq = rep(1, nrow (kmfit2DF))
for (row in 2:nrow (kmfit2DF)) {
  if (kmfit2DF$time[row] > kmfit2DF$time[row-1]) {
    myseq[row] = myseq[row-1]
  }
  else myseq[row] = myseq[row-1] + 1
}
kmfit2DF$Site = factor (ifelse (myseq <= 3, "continental", 
                                ifelse (myseq <= 6, "Mediterranean", 
                                        ifelse (myseq <= 9, "oceanic",NA))))
kmfit2DF$Period = factor (ifelse (myseq == 1 | myseq == 4 | myseq == 7, "P3", 
                                  ifelse (myseq == 2 | myseq == 5 | myseq == 8, "P1", 
                                          ifelse (myseq == 3 | myseq == 6 | myseq == 9, "P2",NA))))
# for fig (c)
kmfit3rDF = getDF(kmfit3r)
kmfit3rDF = as.data.frame (apply(kmfit3rDF, 2, as.numeric) )
myseq = rep(1, nrow (kmfit3rDF))
for (row in 2:nrow (kmfit3rDF)) {
  if (kmfit3rDF$time[row] > kmfit3rDF$time[row-1]) {
    myseq[row] = myseq[row-1]
  }
  else myseq[row] = myseq[row-1] + 1
}
kmfit3rDF$Site = factor (ifelse (myseq <= 3, "continental", 
                                 ifelse (myseq <= 6, "Mediterranean", 
                                         ifelse (myseq <= 9, "oceanic",NA))))
kmfit3rDF$Diameter = factor (ifelse (myseq == 1 | myseq == 4 | myseq == 7, "]0, 1] mm", 
                                     ifelse (myseq == 2 | myseq == 5 | myseq == 8,   "]1, 2] mm", 
                                             ifelse (myseq == 3 | myseq == 6 | myseq == 9,   "]2, 5] mm",NA))))
# for fig (d)
kmfit4_noOnoCRDF = getDF(kmfit4_noOnoCR)
kmfit4_noOnoCRDF = as.data.frame (apply(kmfit4_noOnoCRDF, 2, as.numeric) )
myseq = rep(1, nrow (kmfit4_noOnoCRDF))
for (row in 2:nrow (kmfit4_noOnoCRDF)) {
  if (kmfit4_noOnoCRDF$time[row] > kmfit4_noOnoCRDF$time[row-1]) {
    myseq[row] = myseq[row-1]
  }
  else myseq[row] = myseq[row-1] + 1
}

kmfit4_noOnoCRDF$Site = factor (ifelse (myseq <= 4, "continental", 
                                        ifelse (myseq <= 8, "Mediterranean", NA)))
kmfit4_noOnoCRDF$TopoDiam = factor (ifelse (myseq == 1 | myseq == 5 , "lat_0-1", 
                                            ifelse (myseq == 2 | myseq == 6 , "root_0-1", 
                                                    ifelse (myseq == 3 | myseq == 7 , "lat_1-2",
                                                            ifelse (myseq == 4 | myseq == 8 , "root_1-2", NA)))))

#test = sfit2$surv
with (surviv2DF, table (Site, DiamClass3.st)) 
with (surviv2DF, table (Topology.st, DiamClass3.st)) 
# Kaplan-Meier
survdiff (Surv (surviv2DF$ALiveDays, surviv2DF$Status)~surviv2DF$DiamClass3.st + surviv2DF$Site, rho = 0)


# Cox proportional hazard model
# global
# coef should be compared with 0, when coef > 0, the probability of triggering "death" is higher, that is the ALiveDays tend to be lower.
#                                 when coef < 0, the probability of triggering "death" is lower, that is the ALiveDays tend to be higher.
coxfit1 = coxph (Surv (ALiveDays, Status) ~ Site + DiamClass3.st + Period, data = surviv2DF, method = "breslow")
coxfit1b = coxph (Surv (ALiveDays, Status) ~ Site , data = surviv2DF, method = "breslow")

coxfit1C = coxph (Surv (ALiveDays, Status) ~ DiamClass3.st + Period, 
                  data = surviv2DF[surviv2DF$Site == "continental",], method = "breslow")
coxfit1O = coxph (Surv (ALiveDays, Status) ~ DiamClass3.st + Period , 
                  data = surviv2DF[surviv2DF$Site == "oceanic",], method = "breslow")
coxfit1M = coxph (Surv (ALiveDays, Status) ~ DiamClass3.st + Period , 
                  data = surviv2DF[surviv2DF$Site == "Mediterranean",], method = "breslow")
#
#
coxfit2  = coxph (Surv (ALiveDays, Status) ~ Site + Topology.st+ DiamClass3.st , data = surviv2DF, method = "breslow")
coxfit2C = coxph (Surv (ALiveDays, Status) ~ Topology.st + DiamClass3.st , data = surviv2DF[surviv2DF$Site == "continental",], method = "breslow")
coxfit2O = coxph (Surv (ALiveDays, Status) ~ Topology.st + DiamClass3.st , data = surviv2DF[surviv2DF$Site == "oceanic",], method = "breslow")
coxfit2M = coxph (Surv (ALiveDays, Status) ~ Topology.st + DiamClass3.st , data = surviv2DF[surviv2DF$Site == "Mediterranean",], method = "breslow")

table (surviv2DF$Site, surviv2DF$DiamClass3.st, surviv2DF$Topology.st)
coxfit3 =  coxph (Surv (ALiveDays, Status) ~ Site +  DiamClass3.st , data = surviv2DF, method = "breslow")
coxfit3C =  coxph (Surv (ALiveDays, Status) ~ DiamClass3.st , data = surviv2DF[surviv2DF$Site == "continental",], method = "breslow")
coxfit3M =  coxph (Surv (ALiveDays, Status) ~ DiamClass3.st , data = surviv2DF[surviv2DF$Site == "Mediterranean",], method = "breslow")
coxfit3O =  coxph (Surv (ALiveDays, Status) ~ DiamClass3.st , data = surviv2DF[surviv2DF$Site == "oceanic",], method = "breslow")

coxfit3r =  coxph (Surv (ALiveDays, Status) ~ Site +  DiamClass3.st , data = surviv2DF[surviv2DF$Topology.st == "root",], method = "breslow")
coxfit3Cr =  coxph (Surv (ALiveDays, Status) ~ DiamClass3.st , data = surviv2DF[surviv2DF$Site == "continental"&surviv2DF$Topology.st == "root",], method = "breslow")
coxfit3Mr =  coxph (Surv (ALiveDays, Status) ~ DiamClass3.st , data = surviv2DF[surviv2DF$Site == "Mediterranean"&surviv2DF$Topology.st == "root",], method = "breslow")
coxfit3Or =  coxph (Surv (ALiveDays, Status) ~ DiamClass3.st , data = surviv2DF[surviv2DF$Site == "oceanic"&surviv2DF$Topology.st == "root",], method = "breslow")


# topology
table (surviv2DF$Site, surviv2DF$Topology.st,surviv2DF$DiamClass3.st )
coxfit4 = coxph (Surv (ALiveDays, Status)~ Site+Topology.st , data = surviv2DF[surviv2DF$DiamClass3.st != "2-5",], method = "breslow")
coxfit4fine = coxph (Surv (ALiveDays, Status)~ Site+Topology.st , data = surviv2DF[surviv2DF$DiamClass3.st == "0-1",], method = "breslow")
coxfit4medium = coxph (Surv (ALiveDays, Status)~ Site+Topology.st , data = surviv2DF[surviv2DF$DiamClass3.st == "1-2",], method = "breslow")
coxfit4fineO = coxph (Surv (ALiveDays, Status)~ Topology.st , data = surviv2DF[surviv2DF$Site == "oceanic"&surviv2DF$DiamClass3.st == "0-1",], method = "breslow")
coxfit4fineC = coxph (Surv (ALiveDays, Status)~ Topology.st , data = surviv2DF[surviv2DF$Site == "continental"&surviv2DF$DiamClass3.st == "0-1",], method = "breslow")
coxfit4fineM = coxph (Surv (ALiveDays, Status)~ Topology.st , data = surviv2DF[surviv2DF$Site == "Mediterranean"&surviv2DF$DiamClass3.st == "0-1",], method = "breslow")
coxfit4mediumO = coxph (Surv (ALiveDays, Status)~ Topology.st , data = surviv2DF[surviv2DF$Site == "oceanic"&surviv2DF$DiamClass3.st == "1-2",], method = "breslow")
coxfit4mediumC = coxph (Surv (ALiveDays, Status)~ Topology.st , data = surviv2DF[surviv2DF$Site == "continental"&surviv2DF$DiamClass3.st == "1-2",], method = "breslow")
coxfit4mediumM = coxph (Surv (ALiveDays, Status)~ Topology.st , data = surviv2DF[surviv2DF$Site == "Mediterranean"&surviv2DF$DiamClass3.st == "1-2",], method = "breslow")

anova (coxfit1C)
anova (coxfit3)
#unique (surviv2DF$Topology.st)
#paste(unique (surviv2DF$Site))
#
with (surviv2DF[surviv2DF$Site == "continental",], table(seq_period1.st, Site) )
with (surviv2DF[surviv2DF$Site == "Mediterranean",], table(seq_period1.st, Site) ) 
with (surviv2DF[surviv2DF$Site == "oceanic",], table(seq_period1.st, Site) ) 


########################################
############## PLOT 2 ##################
########################################
makeStairs = function (x, y) {
  x2 = c (x[1], rep (x[2:length (x)], each = 2))
  y2 = c (rep (y[1:(length (y)-1)], each = 2), y[length (y)])
  return (as.data.frame(cbind(x = x2, y =y2)))
  #a = c (1,  2,  3,  5)
  #b = c (10, 30, 40, 60)
  #a2 = c (1,  2,  2,  3,  3,  5,  5 )
  #b2 = c (10, 10, 30, 30, 40, 40, 60)
  #plot (a,b, type = "o")
  #points (a2,b2, type = "o", col = "red")
  #test = makeStairs (a, b)
}

# Plot root survivorship curves
#
allSiteV = c ("oceanic", "continental", "Mediterranean")
allPeriodV = c ("P3", "P1", "P2")
allPeriodLabelV = c ("Dormant", "Early growing", "Late growing")
allDiamV = c ("]0, 1] mm", "]1, 2] mm","]2, 5] mm")
allTopoV = c ( "lat_0-1" , "lat_1-2", "root_0-1", "root_1-2")
allTopoLabelV = c ("Lateral in ]0, 1] mm", "Branched in ]0, 1] mm", "Lateral in ]1, 2] mm", "Branched in ]1, 2] mm")
symbolV = c (21, 24, 23)
colV = c ("blue3", "green4", "red3", "yellow3")
col2V = c (rgb (col2rgb (colV[1])[1,1], col2rgb (colV[1])[2,1],col2rgb (colV[1])[3,1], alpha = 100, maxColorValue = 255), 
           rgb (col2rgb (colV[2])[1,1], col2rgb (colV[2])[2,1],col2rgb (colV[2])[3,1], alpha = 100, maxColorValue = 255), 
           rgb (col2rgb (colV[3])[1,1], col2rgb (colV[3])[2,1],col2rgb (colV[3])[3,1], alpha = 100, maxColorValue = 255),
           rgb (col2rgb (colV[4])[1,1], col2rgb (colV[4])[2,1],col2rgb (colV[4])[3,1], alpha = 100, maxColorValue = 255))
#
pdf (file = paste (addr_output, gsub ("-", "",Sys.Date() ), "_SurvivorshipCurves.pdf",sep = ""), 
     width = 11, height = 9)
par (mfrow = c (2, 2), oma = c (5, 5, 0.5, 0.5), mar = c (0,0,0,0) )
x_max = 650
y_max = 100



#####################
######## (a) ########
plot (0,0, type = "n",
      col = "grey", pch = 20, cex = 1.5, xlab = "", ylab = "",
      xlim = c (0, x_max ), ylim = c (0, y_max), xaxt='n' )
abline (h = 50, col = "grey10", lty = 2)
for (s in 1: length (allSiteV) ) {
  db = kmfit1DF[kmfit1DF$Site == allSiteV[s],]
  db2 = db [(!is.na(db$upper))&(!is.na(db$lower)), ]
  #lines(db$time, db$upper*100, col = col2V[s], type = "s")
  #lines(db$time, db$lower*100, col = col2V[s], type = "s")
  s1 = makeStairs (x = db2$time, y = db2$upper*100)
  s2 = makeStairs (x = db2$time, y = db2$lower*100)
  polygon(c(s1$x, rev(s2$x)), c(s1$y, rev(s2$y) ), col = col2V[s], border = NA)
}
for (s in 1: length (allSiteV) ) {
  db = kmfit1DF[kmfit1DF$Site == allSiteV[s],]
  lines (x = db$time,y = db$surv*100, col = colV[s], type = "s", cex = 2 )
  points (x = db$time,y = db$surv*100, type = "p", col = 1, bg = colV[s],pch = symbolV [s], cex = 1.2)
}
#
#
#axis (2, at = c (0, 20, 40, 60, 80, 100), labels = c (0, 20, 40, 60, 80, 100))
text(x_max, y_max, "(a) Effect of site" , font = 2, cex = 1.2, adj = c(1, 0.5) )
#
# legend
#
start_x = 300
start_y = 90
end_x = 650
end_y = 70
space_x = 16
space_y = 7
rect(xleft = start_x-10, ybottom = end_y, xright = end_x, ytop = start_y+5, col = "grey95", border = NA )
#
rect(xleft = start_x, ybottom = start_y - space_y*0 - space_y*0.4, 
     xright = start_x + space_x*2, ytop = start_y - space_y*0 + space_y*0.4, col = col2V[1], border = NA )
rect(xleft = start_x, ybottom = start_y - space_y*1 - space_y*0.4, 
     xright = start_x + space_x*2, ytop = start_y - space_y*1 + space_y*0.4, col = col2V[2], border = NA )
rect(xleft = start_x, ybottom = start_y - space_y*2 - space_y*0.4, 
     xright = start_x + space_x*2, ytop = start_y - space_y*2 + space_y*0.4, col = col2V[3], border = NA )
ptLocation = c (start_x, start_x+space_x*2)
points (ptLocation, rep (start_y - space_y*0, 2), pch = symbolV[1], bg = colV[1], type = "l", cex = 1.5)
points (ptLocation, rep (start_y - space_y*1, 2), pch = symbolV[2], bg = colV[2], type = "l", cex = 1.5)
points (ptLocation, rep (start_y - space_y*2, 2), pch = symbolV[3], bg = colV[3], type = "l", cex = 1.5)
#
points (mean(ptLocation), start_y - space_y*0, cex = 1.2, pch = symbolV[1], bg = colV[1])
points (mean(ptLocation), start_y - space_y*1, cex = 1.2, pch = symbolV[2], bg = colV[2])
points (mean(ptLocation), start_y - space_y*2, cex = 1.2, pch = symbolV[3], bg = colV[3])
#
text(start_x+ space_x*3, start_y,  
     paste (allSiteV[1], " (" ,nrow(surviv2DF [surviv2DF$Site == allSiteV[1],]), " roots)", sep = "" )  , font = 2, cex = 1, adj = c(0, 0.5)  )
text(start_x+ space_x*3, start_y- space_y*1,  
     paste (allSiteV[2], " (" ,nrow(surviv2DF [surviv2DF$Site == allSiteV[2],]), " roots)", sep = "" ) , font = 2, cex = 1, adj = c(0, 0.5)  )
text(start_x+ space_x*3, start_y- space_y*2,  
     paste (allSiteV[3], " (" ,nrow(surviv2DF [surviv2DF$Site == allSiteV[3],]), " roots)", sep = "" ) , font = 2, cex = 1, adj = c(0, 0.5)  )
#####################
######## (b) ########
plot (0,0, type = "n",
      col = "grey", pch = 20, cex = 1.5, xlab = "", ylab = "",
      xlim = c (0, x_max ), ylim = c (0, y_max), xaxt='n', yaxt='n' )
abline (h = 50, col = "grey10", lty = 2)
for (s in 1: length (allSiteV) ) {
  site = allSiteV[s]
  for (p in c (1, 3, 2) ) {
    period = allPeriodV[p]
    if ((period =="P3" & site == "Mediterranean")| (period =="P3" & site == "oceanic")) {
      next
    }
    db = with (kmfit2DF, kmfit2DF[Site == site & Period == period,] )
    db2 = db [(!is.na(db$upper))&(!is.na(db$lower)), ]
    s1 = makeStairs (x = db2$time, y = db2$upper*100)
    s2 = makeStairs (x = db2$time, y = db2$lower*100)
    polygon(c(s1$x, rev(s2$x)), c(s1$y, rev(s2$y) ), col = col2V[p], border = NA)
  }
}
#
for (p in 1: length (allPeriodV) ) {
  period = allPeriodV[p]
  for (s in 1: length (allSiteV) ) {
    site = allSiteV[s]
    site_Capital = substr(site, 1, 1)
    if ((period =="P3" & site == "Mediterranean")| (period =="P3" & site == "oceanic")) {
      next
    }
    db = with (kmfit2DF, kmfit2DF[Site == site & Period == period,] )
    lines (x = db$time,y = db$surv*100, col = colV[p], type = "s", cex = 2 )
    for  (point in 1:nrow(db)) { # This loop is just for estetic reason
      points (x = db$time[point],y = db$surv[point]*100, type = "p", col = 1, bg = colV[p],
              pch = symbolV [s], cex = 2)
      points (x = db$time[point],y = db$surv[point]*100, type = "p", col = 1, 
              pch = site_Capital, cex = 0.7)
    }
  }
}
text(x_max, y_max, "(b) Effect of period" , font = 2, cex = 1.2, adj = c(1, 0.5) )
#
# legend
#
start_x = 200
start_y = 90
end_x = 650
end_y = 42
space_x = 16
space_y = 7
rect(xleft = start_x-10, ybottom = end_y, xright = end_x, ytop = start_y+5, col = "grey95", border = NA )
#
rect(xleft = start_x, ybottom = start_y - space_y*0 - space_y*0.4, 
     xright = start_x + space_x*2, ytop = start_y - space_y*0 + space_y*0.4, col = col2V[1], border = NA )
#
rect(xleft = start_x, ybottom = start_y - space_y*1 - space_y*0.4, 
     xright = start_x + space_x*2, ytop = start_y - space_y*1 + space_y*0.4, col = col2V[2], border = NA )
rect(xleft = start_x, ybottom = start_y - space_y*2 - space_y*0.4, 
     xright = start_x + space_x*2, ytop = start_y - space_y*2 + space_y*0.4, col = col2V[2], border = NA )
rect(xleft = start_x, ybottom = start_y - space_y*3 - space_y*0.4, 
     xright = start_x + space_x*2, ytop = start_y - space_y*3 + space_y*0.4, col = col2V[2], border = NA )
#
rect(xleft = start_x, ybottom = start_y - space_y*4 - space_y*0.4, 
     xright = start_x + space_x*2, ytop = start_y - space_y*4 + space_y*0.4, col = col2V[3], border = NA )
rect(xleft = start_x, ybottom = start_y - space_y*5 - space_y*0.4, 
     xright = start_x + space_x*2, ytop = start_y - space_y*5 + space_y*0.4, col = col2V[3], border = NA )
rect(xleft = start_x, ybottom = start_y - space_y*6 - space_y*0.4, 
     xright = start_x + space_x*2, ytop = start_y - space_y*6 + space_y*0.4, col = col2V[3], border = NA )
#
ptLocation = c (start_x, start_x+space_x*2)
points (ptLocation, rep (start_y - space_y*0, 2),  col = colV[1], type = "l", cex = 1.5)
points (ptLocation, rep (start_y - space_y*1, 2),  col = colV[2], type = "l", cex = 1.5)
points (ptLocation, rep (start_y - space_y*2, 2),  col = colV[2], type = "l", cex = 1.5)
points (ptLocation, rep (start_y - space_y*3, 2),  col = colV[2], type = "l", cex = 1.5)
points (ptLocation, rep (start_y - space_y*4, 2),  col = colV[3], type = "l", cex = 1.5)
points (ptLocation, rep (start_y - space_y*5, 2),  col = colV[3], type = "l", cex = 1.5)
points (ptLocation, rep (start_y - space_y*6, 2),  col = colV[3], type = "l", cex = 1.5)
#
points (mean(ptLocation), start_y - space_y*0, cex = 1.8, pch = symbolV[2], bg = colV[1])
points (mean(ptLocation), start_y - space_y*1, cex = 1.8, pch = symbolV[1], bg = colV[2])
points (mean(ptLocation), start_y - space_y*2, cex = 1.8, pch = symbolV[2], bg = colV[2])
points (mean(ptLocation), start_y - space_y*3, cex = 1.8, pch = symbolV[3], bg = colV[2])
points (mean(ptLocation), start_y - space_y*4, cex = 1.8, pch = symbolV[1], bg = colV[3])
points (mean(ptLocation), start_y - space_y*5, cex = 1.8, pch = symbolV[2], bg = colV[3])
points (mean(ptLocation), start_y - space_y*6, cex = 1.8, pch = symbolV[3], bg = colV[3])
#
points (mean(ptLocation), start_y - space_y*0, cex = 0.6, pch = "C", bg = colV[1])
points (mean(ptLocation), start_y - space_y*1, cex = 0.6, pch = "O", bg = colV[2])
points (mean(ptLocation), start_y - space_y*2, cex = 0.6, pch = "C", bg = colV[2])
points (mean(ptLocation), start_y - space_y*3, cex = 0.6, pch = "M", bg = colV[2])
points (mean(ptLocation), start_y - space_y*4, cex = 0.6, pch = "O", bg = colV[3])
points (mean(ptLocation), start_y - space_y*5, cex = 0.6, pch = "C", bg = colV[3])
points (mean(ptLocation), start_y - space_y*6, cex = 0.6, pch = "M", bg = colV[3])
#
text(start_x+ space_x*3, start_y,  
     paste (allPeriodLabelV[1], " & " ,allSiteV[2], " (" ,nrow(surviv2DF [surviv2DF$Period == "P3" & surviv2DF$Site == allSiteV[2],]), " roots)", sep = "" ), font = 2, cex = 1, adj = c(0, 0.5)  )
text(start_x+ space_x*3, start_y - space_y*1,  
     paste (allPeriodLabelV[2], " & " ,allSiteV[1], " (" ,nrow(surviv2DF [surviv2DF$Period == "P1" & surviv2DF$Site == allSiteV[1],]), " roots)", sep = "" ), font = 2, cex = 1, adj = c(0, 0.5)  )
text(start_x+ space_x*3, start_y - space_y*2,  
     paste (allPeriodLabelV[2], " & " ,allSiteV[2], " (" ,nrow(surviv2DF [surviv2DF$Period == "P1" & surviv2DF$Site == allSiteV[2],]), " roots)", sep = "" ), font = 2, cex = 1, adj = c(0, 0.5)  )
text(start_x+ space_x*3, start_y - space_y*3,  
     paste (allPeriodLabelV[2], " & " ,allSiteV[3], " (" ,nrow(surviv2DF [surviv2DF$Period == "P1" & surviv2DF$Site == allSiteV[3],]), " roots)", sep = "" ), font = 2, cex = 1, adj = c(0, 0.5)  )
text(start_x+ space_x*3, start_y - space_y*4,  
     paste (allPeriodLabelV[3], " & " ,allSiteV[1], " (" ,nrow(surviv2DF [surviv2DF$Period == "P2" & surviv2DF$Site == allSiteV[1],]), " roots)", sep = "" ), font = 2, cex = 1, adj = c(0, 0.5)  )
text(start_x+ space_x*3, start_y - space_y*5,  
     paste (allPeriodLabelV[3], " & " ,allSiteV[2], " (" ,nrow(surviv2DF [surviv2DF$Period == "P2" & surviv2DF$Site == allSiteV[2],]), " roots)", sep = "" ), font = 2, cex = 1, adj = c(0, 0.5)  )
text(start_x+ space_x*3, start_y - space_y*6,  
     paste (allPeriodLabelV[3], " & " ,allSiteV[3], " (" ,nrow(surviv2DF [surviv2DF$Period == "P2" & surviv2DF$Site == allSiteV[3],]), " roots)", sep = "" ), font = 2, cex = 1, adj = c(0, 0.5)  )
#####################
######## (c) ########
plot (0,0, type = "n",
      col = "grey", pch = 20, cex = 1.5, xlab = "", ylab = "",
      xlim = c (0, x_max), ylim = c (0, y_max), xaxt='n' )
abline (h = 50, col = "grey10", lty = 2)
for (s in 1: length (allSiteV) ) {
  site = allSiteV[s]
  for (d in c (3, 1, 2)) {
    diam = allDiamV[d]
    if ( (diam =="]2, 5] mm" & site == "Mediterranean2") | (diam =="]2, 5] mm" & site == "oceanic")) {
      next
    }
    db = with (kmfit3rDF, kmfit3rDF[Site == site & Diameter == diam,] )
    db2 = db [(!is.na(db$upper))&(!is.na(db$lower)), ]
    s1 = makeStairs (x = db2$time, y = db2$upper*100)
    s2 = makeStairs (x = db2$time, y = db2$lower*100)
    polygon(c(s1$x, rev(s2$x)), c(s1$y, rev(s2$y) ), col = col2V[d], border = NA)
  }
}
#
for (d in 1: length (allDiamV) ) {
  diam = allDiamV[d]
  for (s in 1: length (allSiteV) ) {
    site = allSiteV[s]
    site_Capital = substr(site, 1, 1)
    if ( (diam =="]2, 5] mm" & site == "Mediterranean2") | (diam =="]2, 5] mm" & site == "oceanic")) {
      next
    }
    db = with (kmfit3rDF, kmfit3rDF[Site == site & Diameter == diam,] )
    lines (x = db$time,y = db$surv*100, col = colV[d], type = "s", cex = 2 )
    #
    for  (point in 1:nrow(db)) { # This loop is just for esthetic reason
      points (x = db$time[point],y = db$surv[point]*100, type = "p", col = 1, bg = colV[d],
              pch = symbolV [s], cex = 2)
      points (x = db$time[point],y = db$surv[point]*100, type = "p", col = 1, 
              pch = site_Capital, cex = 0.7)
    }
  }
}
#
# legend
#
start_x = 260
start_y = 90
end_x = 650
end_y = 43
space_x = 16
space_y = 6
rect(xleft = start_x-10, ybottom = end_y, xright = end_x, ytop = start_y+5, col = "grey95", border = NA )
#
#
rect(xleft = start_x, ybottom = start_y - space_y*6 - space_y*0.4, 
     xright = start_x + space_x*2, ytop = start_y - space_y*6 + space_y*0.4, col = col2V[3], border = NA )
rect(xleft = start_x, ybottom = start_y - space_y*7 - space_y*0.4, 
     xright = start_x + space_x*2, ytop = start_y - space_y*7 + space_y*0.4, col = col2V[3], border = NA )
#
rect(xleft = start_x, ybottom = start_y - space_y*0 - space_y*0.4, 
     xright = start_x + space_x*2, ytop = start_y - space_y*0 + space_y*0.4, col = col2V[1], border = NA )
rect(xleft = start_x, ybottom = start_y - space_y*1 - space_y*0.4, 
     xright = start_x + space_x*2, ytop = start_y - space_y*1 + space_y*0.4, col = col2V[1], border = NA )
rect(xleft = start_x, ybottom = start_y - space_y*2 - space_y*0.4, 
     xright = start_x + space_x*2, ytop = start_y - space_y*2 + space_y*0.4, col = col2V[1], border = NA )
#
rect(xleft = start_x, ybottom = start_y - space_y*3 - space_y*0.4, 
     xright = start_x + space_x*2, ytop = start_y - space_y*3 + space_y*0.4, col = col2V[2], border = NA )
rect(xleft = start_x, ybottom = start_y - space_y*4 - space_y*0.4, 
     xright = start_x + space_x*2, ytop = start_y - space_y*4 + space_y*0.4, col = col2V[2], border = NA )
rect(xleft = start_x, ybottom = start_y - space_y*5 - space_y*0.4, 
     xright = start_x + space_x*2, ytop = start_y - space_y*5 + space_y*0.4, col = col2V[2], border = NA )
#
ptLocation = c (start_x, start_x+space_x*2)
points (ptLocation, rep (start_y - space_y*0, 2), col = colV[1],  type = "l", cex = 1.5)
points (ptLocation, rep (start_y - space_y*1, 2), col = colV[1],  type = "l", cex = 1.5)
points (ptLocation, rep (start_y - space_y*2, 2), col = colV[1],  type = "l", cex = 1.5)
points (ptLocation, rep (start_y - space_y*3, 2), col = colV[2],  type = "l", cex = 1.5)
points (ptLocation, rep (start_y - space_y*4, 2), col = colV[2],  type = "l", cex = 1.5)
points (ptLocation, rep (start_y - space_y*5, 2), col = colV[2],  type = "l", cex = 1.5)
points (ptLocation, rep (start_y - space_y*6, 2), col = colV[3],  type = "l", cex = 1.5)
points (ptLocation, rep (start_y - space_y*7, 2), col = colV[3],  type = "l", cex = 1.5)

#
points (mean(ptLocation), start_y - space_y*0, cex = 1.8, pch = symbolV[1], bg = colV[1])
points (mean(ptLocation), start_y - space_y*1, cex = 1.8, pch = symbolV[2], bg = colV[1])
points (mean(ptLocation), start_y - space_y*2, cex = 1.8, pch = symbolV[3], bg = colV[1])
points (mean(ptLocation), start_y - space_y*3, cex = 1.8, pch = symbolV[1], bg = colV[2])
points (mean(ptLocation), start_y - space_y*4, cex = 1.8, pch = symbolV[2], bg = colV[2])
points (mean(ptLocation), start_y - space_y*5, cex = 1.8, pch = symbolV[3], bg = colV[2])
points (mean(ptLocation), start_y - space_y*6, cex = 1.8, pch = symbolV[2], bg = colV[3])
points (mean(ptLocation), start_y - space_y*7, cex = 1.8, pch = symbolV[3], bg = colV[3])
#
points (mean(ptLocation), start_y - space_y*0, cex = 0.6, pch = "O", bg = colV[2])
points (mean(ptLocation), start_y - space_y*1, cex = 0.6, pch = "C", bg = colV[2])
points (mean(ptLocation), start_y - space_y*2, cex = 0.6, pch = "M", bg = colV[2])
points (mean(ptLocation), start_y - space_y*3, cex = 0.6, pch = "O", bg = colV[3])
points (mean(ptLocation), start_y - space_y*4, cex = 0.6, pch = "C", bg = colV[3])
points (mean(ptLocation), start_y - space_y*5, cex = 0.6, pch = "M", bg = colV[3])
points (mean(ptLocation), start_y - space_y*6, cex = 0.6, pch = "C", bg = colV[3])
points (mean(ptLocation), start_y - space_y*7, cex = 0.6, pch = "M", bg = colV[3])

#
text(start_x+ space_x*3, start_y - space_y*0,  
     paste (allDiamV[1], " & " ,allSiteV[1], " (" ,nrow(surviv2DF [surviv2DF$DiamClass3.st == "0-1" & surviv2DF$Site == allSiteV[1] & surviv2DF$Topology.st == "root",]), " roots)", sep = "" ), font = 2, cex = 1, adj = c(0, 0.5)  )
text(start_x+ space_x*3, start_y - space_y*1,  
     paste (allDiamV[1], " & " ,allSiteV[2], " (" ,nrow(surviv2DF [surviv2DF$DiamClass3.st == "0-1" & surviv2DF$Site == allSiteV[2] & surviv2DF$Topology.st == "root",]), " roots)", sep = "" ), font = 2, cex = 1, adj = c(0, 0.5)  )
text(start_x+ space_x*3, start_y - space_y*2,  
     paste (allDiamV[1], " & " ,allSiteV[3], " (" ,nrow(surviv2DF [surviv2DF$DiamClass3.st == "0-1" & surviv2DF$Site == allSiteV[3] & surviv2DF$Topology.st == "root",]), " roots)", sep = "" ), font = 2, cex = 1, adj = c(0, 0.5)  )
text(start_x+ space_x*3, start_y - space_y*3,  
     paste (allDiamV[2], " & " ,allSiteV[1], " (" ,nrow(surviv2DF [surviv2DF$DiamClass3.st == "1-2" & surviv2DF$Site == allSiteV[1] & surviv2DF$Topology.st == "root",]), " roots)", sep = "" ), font = 2, cex = 1, adj = c(0, 0.5)  )
text(start_x+ space_x*3, start_y - space_y*4,  
     paste (allDiamV[2], " & " ,allSiteV[2], " (" ,nrow(surviv2DF [surviv2DF$DiamClass3.st == "1-2" & surviv2DF$Site == allSiteV[2] & surviv2DF$Topology.st == "root",]), " roots)", sep = "" ), font = 2, cex = 1, adj = c(0, 0.5)  )
text(start_x+ space_x*3, start_y - space_y*5,  
     paste (allDiamV[2], " & " ,allSiteV[3], " (" ,nrow(surviv2DF [surviv2DF$DiamClass3.st == "1-2" & surviv2DF$Site == allSiteV[3] & surviv2DF$Topology.st == "root",]), " roots)", sep = "" ), font = 2, cex = 1, adj = c(0, 0.5)  )
text(start_x+ space_x*3, start_y- space_y*6,  
     paste (allDiamV[3], " & " ,allSiteV[2], " (" ,nrow(surviv2DF [surviv2DF$DiamClass3.st == "2-5" & surviv2DF$Site == allSiteV[2] & surviv2DF$Topology.st == "root",]), " roots)", sep = "" ), font = 2, cex = 1, adj = c(0, 0.5)  )
text(start_x+ space_x*3, start_y- space_y*7,  
     paste (allDiamV[3], " & " ,allSiteV[3], " (" ,nrow(surviv2DF [surviv2DF$DiamClass3.st == "2-5" & surviv2DF$Site == allSiteV[3] & surviv2DF$Topology.st == "root",]), " roots)", sep = "" ), font = 2, cex = 1, adj = c(0, 0.5)  )

axis (1, at = seq (0, x_max, 100), labels = seq (0, x_max, 100))
text(x_max, y_max, "(c) Effect of root diameter (lateral roots excluded)" , font = 2, cex = 1.2, adj = c(1, 0.5) )
#
#####################
######## (d) ########
plot (0,0, type = "n",
      col = "grey", pch = 20, cex = 1.5, xlab = "", ylab = "",
      xlim = c (0, x_max), ylim = c (0, y_max), xaxt='n', yaxt='n' )
abline (h = 50, col = "grey10", lty = 2)
for (s in 2: length (allSiteV) ) {
  site = allSiteV[s]
  for (t in c (1, 2, 3, 4)) {
    topo = allTopoV[t]
    #if ( topo =="Lateral, ]1, 2] mm" & site == "Mediterranean" ) {
    #  next
    #}
    db = with (kmfit4_noOnoCRDF, kmfit4_noOnoCRDF[Site == site & TopoDiam == topo,] )
    db2 = db [(!is.na(db$upper))&(!is.na(db$lower)), ]
    s1 = makeStairs (x = db2$time, y = db2$upper*100)
    s2 = makeStairs (x = db2$time, y = db2$lower*100)
    polygon(c(s1$x, rev(s2$x)), c(s1$y, rev(s2$y) ), col = col2V[t], border = NA)
  }
}
#
for (t in c (3, 4, 2, 1) ) {
  topo = allTopoV[t]
  for (s in 2: length (allSiteV) ) {
    site = allSiteV[s]
    site_Capital = substr(site, 1, 1)
    #if ( (diam =="]2, 5] mm" & site == "Mediterranean2") | (diam =="]2, 5] mm" & site == "oceanic")) {
    #  next
    #}
    db = with (kmfit4_noOnoCRDF, kmfit4_noOnoCRDF[Site == site & TopoDiam == topo,] )
    lines (x = db$time,y = db$surv*100, col = colV[t], type = "s", cex = 2 )
    #
    for  (point in 1:nrow(db)) { # This loop is just for esthetic reason
      points (x = db$time[point],y = db$surv[point]*100, type = "p", col = 1, bg = colV[t],
              pch = symbolV [s], cex = 2)
      points (x = db$time[point],y = db$surv[point]*100, type = "p", col = 1, 
              pch = site_Capital, cex = 0.7)
    }
  }
}
#
# legend
#
start_x = 130
start_y = 90
end_x = 650
end_y = 43
space_x = 16
space_y = 6
rect(xleft = start_x-10, ybottom = end_y, xright = end_x, ytop = start_y+5, col = "grey95", border = NA )
#
#
rect(xleft = start_x, ybottom = start_y - space_y*0 - space_y*0.4, 
     xright = start_x + space_x*2, ytop = start_y - space_y*0 + space_y*0.4, col = col2V[1], border = NA )
rect(xleft = start_x, ybottom = start_y - space_y*1 - space_y*0.4, 
     xright = start_x + space_x*2, ytop = start_y - space_y*1 + space_y*0.4, col = col2V[2], border = NA )
rect(xleft = start_x, ybottom = start_y - space_y*2 - space_y*0.4, 
     xright = start_x + space_x*2, ytop = start_y - space_y*2 + space_y*0.4, col = col2V[3], border = NA )
#
rect(xleft = start_x, ybottom = start_y - space_y*3 - space_y*0.4, 
     xright = start_x + space_x*2, ytop = start_y - space_y*3 + space_y*0.4, col = col2V[4], border = NA )
rect(xleft = start_x, ybottom = start_y - space_y*4 - space_y*0.4, 
     xright = start_x + space_x*2, ytop = start_y - space_y*4 + space_y*0.4, col = col2V[1], border = NA )
rect(xleft = start_x, ybottom = start_y - space_y*5 - space_y*0.4, 
     xright = start_x + space_x*2, ytop = start_y - space_y*5 + space_y*0.4, col = col2V[2], border = NA )
#
rect(xleft = start_x, ybottom = start_y - space_y*6 - space_y*0.4, 
     xright = start_x + space_x*2, ytop = start_y - space_y*6 + space_y*0.4, col = col2V[3], border = NA )
rect(xleft = start_x, ybottom = start_y - space_y*7 - space_y*0.4, 
     xright = start_x + space_x*2, ytop = start_y - space_y*7 + space_y*0.4, col = col2V[4], border = NA )
#
ptLocation = c (start_x, start_x+space_x*2)
points (ptLocation, rep (start_y - space_y*0, 2), col = colV[1],  type = "l", cex = 1.5)
points (ptLocation, rep (start_y - space_y*1, 2), col = colV[2],  type = "l", cex = 1.5)
points (ptLocation, rep (start_y - space_y*2, 2), col = colV[3],  type = "l", cex = 1.5)
points (ptLocation, rep (start_y - space_y*3, 2), col = colV[4],  type = "l", cex = 1.5)
points (ptLocation, rep (start_y - space_y*4, 2), col = colV[1],  type = "l", cex = 1.5)
points (ptLocation, rep (start_y - space_y*5, 2), col = colV[2],  type = "l", cex = 1.5)
points (ptLocation, rep (start_y - space_y*6, 2), col = colV[3],  type = "l", cex = 1.5)
points (ptLocation, rep (start_y - space_y*7, 2), col = colV[4],  type = "l", cex = 1.5)
#
points (mean(ptLocation), start_y - space_y*0, cex = 1.8, pch = symbolV[2], bg = colV[1])
points (mean(ptLocation), start_y - space_y*1, cex = 1.8, pch = symbolV[2], bg = colV[2])
points (mean(ptLocation), start_y - space_y*2, cex = 1.8, pch = symbolV[2], bg = colV[3])
points (mean(ptLocation), start_y - space_y*3, cex = 1.8, pch = symbolV[2], bg = colV[4])
points (mean(ptLocation), start_y - space_y*4, cex = 1.8, pch = symbolV[3], bg = colV[1])
points (mean(ptLocation), start_y - space_y*5, cex = 1.8, pch = symbolV[3], bg = colV[2])
points (mean(ptLocation), start_y - space_y*6, cex = 1.8, pch = symbolV[3], bg = colV[3])
points (mean(ptLocation), start_y - space_y*7, cex = 1.8, pch = symbolV[3], bg = colV[4])

#
points (mean(ptLocation), start_y - space_y*0, cex = 0.6, pch = "C")
points (mean(ptLocation), start_y - space_y*1, cex = 0.6, pch = "C")
points (mean(ptLocation), start_y - space_y*2, cex = 0.6, pch = "C")
points (mean(ptLocation), start_y - space_y*3, cex = 0.6, pch = "C")
points (mean(ptLocation), start_y - space_y*4, cex = 0.6, pch = "M")
points (mean(ptLocation), start_y - space_y*5, cex = 0.6, pch = "M")
points (mean(ptLocation), start_y - space_y*6, cex = 0.6, pch = "M")
points (mean(ptLocation), start_y - space_y*7, cex = 0.6, pch = "M")
#
text(start_x+ space_x*3, start_y - space_y*0,  
     paste (allTopoLabelV[1], " & " ,allSiteV[2], " (" ,nrow(surviv2DF [surviv2DF$TopoDiam == "lat_0-1" & surviv2DF$Site == allSiteV[2] ,]), " roots)", sep = "" ), font = 2, cex = 1, adj = c(0, 0.5)  )
text(start_x+ space_x*3, start_y - space_y*1,  
     paste (allTopoLabelV[2], " & " ,allSiteV[2], " (" ,nrow(surviv2DF [surviv2DF$TopoDiam == "lat_1-2" & surviv2DF$Site == allSiteV[2] ,]), " roots)", sep = "" ), font = 2, cex = 1, adj = c(0, 0.5)  )
text(start_x+ space_x*3, start_y - space_y*2,  
     paste (allTopoLabelV[3], " & " ,allSiteV[2], " (" ,nrow(surviv2DF [surviv2DF$TopoDiam == "root_0-1" & surviv2DF$Site == allSiteV[2] ,]), " roots)", sep = "" ), font = 2, cex = 1, adj = c(0, 0.5)  )
text(start_x+ space_x*3, start_y - space_y*3,  
     paste (allTopoLabelV[4], " & " ,allSiteV[2], " (" ,nrow(surviv2DF [surviv2DF$TopoDiam == "root_1-2" & surviv2DF$Site == allSiteV[2] ,]), " roots)", sep = "" ), font = 2, cex = 1, adj = c(0, 0.5)  )
text(start_x+ space_x*3, start_y - space_y*4,  
     paste (allTopoLabelV[1], " & " ,allSiteV[3], " (" ,nrow(surviv2DF [surviv2DF$TopoDiam == "lat_0-1" & surviv2DF$Site == allSiteV[3] ,]), " roots)", sep = "" ), font = 2, cex = 1, adj = c(0, 0.5)  )
text(start_x+ space_x*3, start_y - space_y*5,  
     paste (allTopoLabelV[2], " & " ,allSiteV[3], " (" ,nrow(surviv2DF [surviv2DF$TopoDiam == "lat_1-2" & surviv2DF$Site == allSiteV[3] ,]), " roots)", sep = "" ), font = 2, cex = 1, adj = c(0, 0.5)  )
text(start_x+ space_x*3, start_y- space_y*6,  
     paste (allTopoLabelV[3], " & " ,allSiteV[3], " (" ,nrow(surviv2DF [surviv2DF$TopoDiam == "root_0-1" & surviv2DF$Site == allSiteV[3] ,]), " roots)", sep = "" ), font = 2, cex = 1, adj = c(0, 0.5)  )
text(start_x+ space_x*3, start_y- space_y*7,  
     paste (allTopoLabelV[4], " & " ,allSiteV[3], " (" ,nrow(surviv2DF [surviv2DF$TopoDiam == "root_1-2" & surviv2DF$Site == allSiteV[3] ,]), " roots)", sep = "" ), font = 2, cex = 1, adj = c(0, 0.5)  )
#
axis (1, at = seq (0, x_max, 100), labels = seq (0, x_max, 100))
text(x_max, y_max, "(d) Effect of root topology within each diameter class" , font = 2, cex = 1.2, adj = c(1, 0.5) )

#
mtext ("Number of days (d)", side =1, line = 3 , adj = 0.5, font = 2, outer = T , 
       col = "black", cex = 1.2)
mtext ("Survivorship (%)", side =2, line = 3 , adj = 0.5, font = 2, outer = T , 
       col = "black", cex = 1.2)

dev.off()

# END #